<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:java="http://xml.apache.org/xslt/java"
extension-element-prefixes="java">

<!-- handling of the different types of params on a service form 
  - these now only output the selection box/text box etc, not the name -->

<!-- boolean params -->
  <xsl:template match="param[@type='boolean']">
    <xsl:param name="default" select="@default"/>
    <xsl:variable name="pname" select='@name'/>
    <xsl:variable name='pdisplay' select='ancestor::service/display/param[@name=$pname]'/>
    <select name='{@shortname}'>
      <option value="0"><xsl:if test="$default='0'"><xsl:attribute name="selected"></xsl:attribute></xsl:if><xsl:value-of select='$pdisplay/option[@name="0"]'/></option>
      <option value="1"><xsl:if test="$default='1'"><xsl:attribute name="selected"></xsl:attribute></xsl:if><xsl:value-of select='$pdisplay/option[@name="1"]'/></option>
    </select>
  </xsl:template>
  
  <!-- integer params -->
  <xsl:template match="param[@type='integer']">
    <xsl:param name="default" select="@default"/>
    <input type="text" name="{@shortname}" size="3" value="{$default}"/>
  </xsl:template>

  <!-- single selection enum params -->
  <xsl:template match="param[@type='enum_single']">
    <xsl:param name="default" select="@default"/>
    <xsl:variable name="pname"><xsl:value-of select='@name'/></xsl:variable>
    <xsl:variable name='pdisplay' select='ancestor::service/display/param[@name=$pname]'/>
    <xsl:variable name="current"><xsl:value-of select="$default"/></xsl:variable>
    <select name="{@shortname}">
      <xsl:for-each select="option">
	<xsl:variable name='op_name' select='@name'/>
	<option value="{@name}"><xsl:if test="@name=$current"><xsl:attribute name="selected"></xsl:attribute></xsl:if><xsl:value-of select='$pdisplay/option[@name=$op_name]'/></option>
      </xsl:for-each>
    </select>
  </xsl:template>


  <!-- multiple selection enum params -->
  <!-- how to do defaults for this?? -->
  <xsl:template match="param[@type='enum_multi']">
    <xsl:variable name="pname" select='@name'/>
    <xsl:variable name='pdisplay' select='ancestor::service/display/param[@name=$pname]'/>
    <select name="{@shortname}" size='2'><xsl:attribute name="multiple"></xsl:attribute>
      <xsl:for-each select="option">
	<xsl:variable name='op_name' select='@name'/>
	<option value="{@name}"><xsl:value-of select='$pdisplay/option[@name=$op_name]'/></option>
      </xsl:for-each>
    </select>
  </xsl:template>
 
  <!-- string params -->
  <xsl:template match="param[@type='string']">
    <xsl:param name="default" select="@default"/>
    <xsl:variable name="pname" select='@name'/>
    <input type="text" name="{@shortname}" size="50" value="{$default}"/>
  </xsl:template>
  
  <!-- multi params - params that are combinations of other params -->
  <xsl:template match="param[@type='multi']">
    <xsl:variable name="parent" select="@name"/>
    <table>
      <tr><td colspan='10'><xsl:value-of select="ancestor::service/display/param[@name=$parent]/name"/></td></tr>
      <tr>
	<xsl:for-each select="param">
	  <xsl:variable name='pname' select='@name'/>
	  <td><xsl:value-of select="ancestor::service/display/param[@name=$pname]/name"/></td>
	</xsl:for-each>
      </tr>
      <xsl:apply-templates select="." mode="contents"><xsl:with-param name="occurs" select="@occurs"/></xsl:apply-templates>
    </table>
  </xsl:template>

  <xsl:template match="param[@type='multi']" mode="contents">
    <xsl:param name="occurs">1</xsl:param>
    <xsl:variable name="pos" select="@occurs - $occurs"/>
    <xsl:choose>
      <xsl:when test="default">
	<tr><xsl:for-each select="param">
	    <td><xsl:if test="not(@ignore) or  @ignore != $pos">
	    <xsl:variable name="pname" select="@name"/>
	    <xsl:variable name="values"><xsl:value-of  select="../default[@name=$pname]"/></xsl:variable>
	    <xsl:apply-templates select='.'><xsl:with-param name="default"><xsl:value-of select="java:org.greenstone.gsdl3.util.XSLTUtil.getNumberedItem($values, $occurs)"/></xsl:with-param></xsl:apply-templates>
	      </xsl:if></td>
	  </xsl:for-each></tr> 
      </xsl:when>
      <xsl:otherwise>
	<tr><xsl:for-each select="param">
	    <td><xsl:if test="not(@ignore) or  @ignore != $pos">
	      <xsl:variable name="pname" select="@name"/>
	      <xsl:apply-templates select='.'/>
	     </xsl:if></td>
	  </xsl:for-each></tr> 
      </xsl:otherwise>
    </xsl:choose>
    <!-- recursively call this template to get multiple entries -->
    <xsl:if test="$occurs &gt; 1">
      <xsl:apply-templates select="." mode="contents"><xsl:with-param name="occurs" select="$occurs - 1"/></xsl:apply-templates>
    </xsl:if>
  </xsl:template>


</xsl:stylesheet>  
